@@ -1,7 +1,6 @@
-var _curry1 = require('./internal/_curry1');
-var _isString = require('./internal/_isString');
-var _slice = require('./internal/_slice');
+var _curry1 = /*#__PURE__*/require('./internal/_curry1');
 
+var _isString = /*#__PURE__*/require('./internal/_isString');
 
 /**
  * Returns a new list or string with the elements or characters in reverse
@@ -27,7 +26,9 @@ var _slice = require('./internal/_slice');
  *      R.reverse('a');        //=> 'a'
  *      R.reverse('');         //=> ''
  */
-module.exports = _curry1(function reverse(list) {
-  return _isString(list) ? list.split('').reverse().join('') :
-                           _slice(list).reverse();
+
+
+var reverse = /*#__PURE__*/_curry1(function reverse(list) {
+  return _isString(list) ? list.split('').reverse().join('') : Array.prototype.slice.call(list, 0).reverse();
 });
+module.exports = reverse;
\ No newline at end of file
